@@ -245,7 +245,6 @@ class OptionEngine(BaseEngine):
         model_name: str,
         interest_rate: float,
         chain_underlying_map: Dict[str, str],
-        inverse: bool = False,
         precision: int = 0
     ) -> None:
         """"""
@@ -271,7 +270,6 @@ class OptionEngine(BaseEngine):
 
         pricing_model = PRICING_MODELS[model_name]
         portfolio.set_pricing_model(pricing_model)
-        portfolio.set_inverse(inverse)
         portfolio.set_precision(precision)
 
         portfolio_settings: dict = self.setting.setdefault("portfolio_settings", {})
@@ -279,7 +277,6 @@ class OptionEngine(BaseEngine):
             "model_name": model_name,
             "interest_rate": interest_rate,
             "chain_underlying_map": chain_underlying_map,
-            "inverse": inverse,
             "precision": precision
         }
         self.save_setting()
